<?php include('./config/db.php'); ?>
<?php 

function validaRut($rutCompleto) {
	if (!preg_match("/^[0-9]+-[0-9kK]{1}/",$rutCompleto)) return false;
		$rut = explode('-', $rutCompleto);
		return strtolower($rut[1]) == dv($rut[0]);
	}
	function dv ( $T ) {
		$M=0;$S=1;
		for(;$T;$T=floor($T/10))
			$S=($S+$T%10*(9-$M++%6))%11;
		return $S?$S-1:'k';
	}

	function limpiaHTML($cadena){
		$arregloVocal = array('á'=>'&aacute;', 'é'=>'&eacute;', 'í'=>'&iacute;', 'ó'=>'&oacute;', 'ú'=>'&uacute;',
		'Á'=>'&Aacute;', 'É'=>'&Eacute;', 'Í'=>'&Iacute;', 'Ó'=>'&Oacute;', 'Ú'=>'&Uacute;','ñ'=>'&ntilde;', 
		'Ñ'=>'&Ntilde;','´'=>'','¨'=>'' );
	
		$cadena = strtr($cadena, $arregloVocal);
		return $cadena;
	}

	function reestableceHTML($cadena){
		$arregloVocal = array('á'=>'a', 'é'=>'e', 'í'=>'i', 'ó'=>'o', 'ú'=>'u',
		'Á'=>'A', 'É'=>'E', 'Í'=>'I', 'Ó'=>'O', 'Ú'=>'U','ñ'=>'n', 
		'Ñ'=>'N','´'=>'','¨'=>'' );
	
		$cadena = strtr($cadena, $arregloVocal);
		return $cadena;
	}

	function validaImagen($cadena){
		$extension = array('image/png','image/jpeg','image/jpg');
		$valida=false;
	
		foreach($extension as $ex){
			if($ex==$cadena){
				$valida=true;
			}
		}
		return $valida;
	}

	function validaTodo($cadena){
		$extension = array('image/png','image/jpeg','image/jpg','application/pdf','application/vnd.ms-powerpoint',
	'application/msword','application/vnd.ms-excel');
		$valida=false;
	
		foreach($extension as $ex){
			if($ex==$cadena){
				$valida=true;
			}
		}
		return $valida;
	}

	function validaExtension($cadena){
		$extension = array('application/pdf');
		$valida=false;
	
		foreach($extension as $ex){
			if($ex==$cadena){
				$valida=true;
			}
		}
		return $valida;
	}

	function validaPesoArchivo($PesoArchivo, $PesoPermitido){
		$valida=false;
		if($PesoArchivo <= $PesoPermitido){
				$valida=true;
		}
		return $valida;
	}

	function imprimeMes($mesEntero){
		$mes="";
		switch($mesEntero){
			case 1:
				$mes="Enero";
			break;
			case 2:
				$mes="Febrero";
			break;
			case 3:
				$mes="Marzo";
			break;
			case 4:
				$mes="Abril";
			break;
			case 5:
				$mes="Mayo";
			break;
			case 6:
				$mes="Junio";
			break;
			case 7:
				$mes="Julio";
			break;
			case 8:
				$mes="Agosto";
			break;
			case 9:
				$mes="Septiembre";
			break;
			case 10:
				$mes="Octubre";
			break;
			case 11:
				$mes="Noviembre";
			break;
			case 12:
				$mes="Diciembre";
			break;
		}
		return $mes;
	}


?>