<?php include('./templates/cabecera.php'); ?>
<?php include('./config/db.php'); ?>
<?php include('funciones.php'); ?>
<?php 
$html = "documentos.php";
if(!$_GET){
    echo "<script>location.href='$html?pagina=1';</script>";
}

if($_SESSION['perfil'] == 2){
    echo "<script>location.href='index.php?pagina=1';</script>";
}

$error = "";
$ok = "";
$txtFiltro=(isset($_GET['txtFiltro']))?$_GET['txtFiltro']:"";
$totalPaginas = 10;
$paginadorSalto = 9;
$txtId=(isset($_POST['txtId']))?$_POST['txtId']:"";
if(isset($_POST['chkActivo']) == "on"){
    $chkActivo = 1; //activo
}else{
    $chkActivo = 0; //inactivo
}
$txtNomDocumento=(isset($_POST['txtNomDocumento']))?$_POST['txtNomDocumento']:"";
$action=(isset($_POST['action']))?$_POST['action']:"";

//variables de adjunto
$txtFileNameImagen=(isset($_FILES['txtFileImagen']['name']))?$_FILES['txtFileImagen']['name']:"";
$txtFileTypeImagen=(isset($_FILES['txtFileImagen']['type']))?$_FILES['txtFileImagen']['type']:"";
$txtFileSizeImagen=(isset($_FILES['txtFileImagen']['size']))?$_FILES['txtFileImagen']['size']:"";
$txtFileTmpImagen=(isset($_FILES['txtFileImagen']['tmp_name']))?$_FILES['txtFileImagen']['tmp_name']:"";
//echo($txtFileTmpImagen);

$txtFileNameAdjunto=(isset($_FILES['txtFileAdjunto']['name']))?$_FILES['txtFileAdjunto']['name']:"";
$txtFileTypeAdjunto=(isset($_FILES['txtFileAdjunto']['type']))?$_FILES['txtFileAdjunto']['type']:"";
$txtFileSizeAdjunto=(isset($_FILES['txtFileAdjunto']['size']))?$_FILES['txtFileAdjunto']['size']:"";
$txtFileTmpAdjunto=(isset($_FILES['txtFileAdjunto']['tmp_name']))?$_FILES['txtFileAdjunto']['tmp_name']:"";

$txtFileNameImagen = reestableceHTML($txtFileNameImagen);
$txtFileNameAdjunto = reestableceHTML($txtFileNameAdjunto);

switch($action){
    case "Agregar":
        try{
            $sql=$conexion->prepare("SELECT * FROM documentos where nombreDocumento LIKE :nombre;");  
            $sql->bindParam(":nombre",$txtNomDocumento);
            $sql->execute();
            if($sql->rowCount() > 0){
                $error = $error."-El nombre del documento ingresado ya se encuentra en nuestros registros<br>";
            }
        }catch (Exception $err) {
            echo ("Ha ocurrido un error en la solicitud. ");  
        }
        if($txtFileNameImagen != ""){
            if(!validaImagen($txtFileTypeImagen)){
                $error = $error."-La imagen adjunta no cumple con los formatos establecidos (JPG,PNG)<br>";
            }else{
                move_uploaded_file($txtFileTmpImagen,$document_root."/archivos/img/".$txtFileNameImagen);
            }
        }else{
            $txtFileNameImagen = "default.jpg";
        }
        if(!validaPesoArchivo($txtFileSizeImagen, $totalZise) or !validaPesoArchivo($txtFileSizeAdjunto, $totalZise)){
            $error = $error."-El tamaño de los adjuntos no debe ser superior a 10MB<br>";
        }
        if($txtFileNameAdjunto != ""){
            if(!validaExtension($txtFileTypeAdjunto)){
                $error = $error."-El archivo adjunto no cumple con los formatos establecidos (PDF)<br>";
            }else{
                move_uploaded_file($txtFileTmpAdjunto,$document_root."/archivos/doc/".$txtFileNameAdjunto);
            }
        }else{
            $txtFileNameAdjunto = "default.pdf";
        }
        
        if(strlen($error) == 0){
            try{
                $sql=$conexion->prepare("INSERT INTO documentos (activo,nombreDocumento,imagen,adjunto) 
                VALUES (:activo,:nombreDocumento,:imagen,:adjunto);"); 
                $sql->bindParam(":activo",$chkActivo);
                $sql->bindParam(":nombreDocumento",$txtNomDocumento);
                $sql->bindParam(":imagen",$txtFileNameImagen);
                $sql->bindParam(":adjunto",$txtFileNameAdjunto);
                $sql->execute();
                echo("<script>alert('Se ha ingresado el registro satisfactoriamente');</script>");
                echo "<script>location.href='$html';</script>";
            }catch (Exception $err) {
                $error = ("Ha ocurrido un error al agregar la solicitud");    
                //throw $th;
            }
        }
        break;
    case "Modificar":
            if($txtFileNameImagen != ""){
                if(!validaImagen($txtFileTypeImagen)){
                    $error = $error."-La imagen adjunta no cumple con los formatos establecidos (JPG,PNG)<br>";
                }
            }
            if($txtFileNameAdjunto != ""){
                if(!validaExtension($txtFileTypeAdjunto)){
                    $error = $error."-El archivo adjunto no cumple con los formatos establecidos (PDF)<br>";
                }
            }
            if(!validaPesoArchivo($txtFileSizeImagen, $totalZise) or !validaPesoArchivo($txtFileSizeAdjunto, $totalZise)){
                $error = $error."-El tamaño de los adjuntos no debe ser superior a 15MB<br>";
            }
            if(strlen($error) == 0){
                try{
                    $sql=$conexion->prepare("SELECT imagen, adjunto from documentos where id=:id;");  
                    $sql->bindParam(":id",$txtId);
                    $sql->execute();
                    $listaDocumentos = $sql->fetch(PDO::FETCH_LAZY);

                    $sql=$conexion->prepare("UPDATE documentos SET activo=:activo, nombreDocumento=:nombreDocumento  
                    where id=:id;");  
                    $sql->bindParam(":id",$txtId);
                    $sql->bindParam(":activo",$chkActivo);
                    $sql->bindParam(":nombreDocumento",$txtNomDocumento);
                    $sql->execute();
                    if($txtFileNameImagen != ""){
                        if(isset($listaDocumentos['imagen']) && ($listaDocumentos['imagen'] != "default.jpg")){
                            if(file_exists($document_root."/archivos/img/".$listaDocumentos['imagen'])){
                                unlink($document_root."/archivos/img/".$listaDocumentos['imagen']);
                            }
                        }
                        move_uploaded_file($txtFileTmpImagen,$document_root."/archivos/img/".$txtFileNameImagen);
                        $sql=$conexion->prepare("UPDATE documentos SET imagen=:imagen where id=:id;");  
                        $sql->bindParam(":id",$txtId);
                        $sql->bindParam(":imagen",$txtFileNameImagen);
                        $sql->execute();
                    }
                    if($txtFileNameAdjunto != ""){
                        if(isset($listaDocumentos['adjunto']) && ($listaDocumentos['adjunto'] != "default.pdf")){
                            if(file_exists($document_root."/archivos/doc/".$listaDocumentos['adjunto'])){
                                unlink($document_root."/archivos/doc/".$listaDocumentos['adjunto']);
                            }
                        }
                        move_uploaded_file($txtFileTmpAdjunto,$document_root."/archivos/doc/".$txtFileNameAdjunto);
                        $sql=$conexion->prepare("UPDATE documentos SET adjunto=:adjunto where id=:id;");  
                        $sql->bindParam(":id",$txtId);
                        $sql->bindParam(":adjunto",$txtFileNameAdjunto);
                        $sql->execute();
                    }
                    echo("<script>alert('Se ha modificado el registro satisfactoriamente');</script>");
                    echo "<script>location.href='$html';</script>";
                }catch (Exception $err) {
                    $error = ("Ha ocurrido un error al modificar la solicitud");    
                    //throw $th;
                }
            }
        break;
    case "Volver":
        //header("location:index.php");
        echo "<script>location.href='index.php';</script>";
        break;
    case "Seleccionar":
        try{
            $sql=$conexion->prepare("SELECT * FROM documentos where id=:id;");  
            $sql->bindParam(":id",$txtId);
            $sql->execute();
            $Documentos = $sql->fetch(PDO::FETCH_LAZY); //1 solo atributo, para trabajar con él
            $txtId= $Documentos['id'];
            $chkActivo = $Documentos['activo']; //0 - inactivo / 1 - activo
            $txtNomDocumento = $Documentos['nombreDocumento']; 
            $txtFileNameImagen = "--><strong>".$Documentos['imagen']."</strong>"; 
            $txtFileNameAdjunto = "--><strong>".$Documentos['adjunto']."</strong>"; 
        }catch (Exception $err) {
            $error = ("Ha ocurrido un error al seleccionar el registro");    
            //throw $th;
        }
        break;
}

$sqlDocumento="SELECT id, nombreDocumento, imagen, adjunto FROM documentos";  
if($txtFiltro!="" ){
    $sqlDocumento = $sqlDocumento . " where nombreDocumento LIKE :id or imagen LIKE :id or adjunto LIKE :id ";
}
try{
    $sql=$conexion->prepare($sqlDocumento); 
    if($txtFiltro!="" ){
        $txtFiltro2=limpiaHTML("%".$txtFiltro."%");
        $sql->bindParam(":id",$txtFiltro2);
    }

    $sql->execute();
    if($sql->rowCount() > 0){
        $totalDatos = $sql->rowCount();
        $paginas = $totalDatos/$totalPaginas;
        $paginas = ceil($paginas);
    }else{
        $paginas = 1;
    }

}catch (Exception $err) {
    echo ("Ha ocurrido un error en la solicitud. "); 
}

if(is_null($_GET['pagina'])){
    $getPagina=0;
}else{
    $getPagina = intval($_GET['pagina']);
}

$iniciar = ($getPagina-1) * $totalPaginas;
$sqlDocumento=$sqlDocumento." ORDER BY id LIMIT :iniciar,:totalPaginas;";

try{
    $sql=$conexion->prepare($sqlDocumento); 
    if($txtFiltro!="" ){
        $txtFiltro2=limpiaHTML("%".$txtFiltro."%");
        $sql->bindParam(":id",$txtFiltro2);
    }
    $sql->bindParam(":iniciar",$iniciar, PDO::PARAM_INT);
    $sql->bindParam(":totalPaginas",$totalPaginas, PDO::PARAM_INT);
    $sql->execute();
}catch (Exception $err) {
    echo ("Ha ocurrido un error en la solicitud. ");    
    throw $err;
}
$listaDocumentos = $sql->fetchAll(PDO::FETCH_ASSOC); //almacena todos los registros como arreglo
?>
<div class="col-md-4">
    <div class="card">
        <div class="card-header">
            <h4>Documentos<h4/>
        </div>
        <div class="card-body">
                <?php if(strlen($error) > 0) {?>
                    <div class='alert alert-danger' role="alert">
                        <?php echo $error; ?>
                    </div>
                <?php }?>
            <form method="POST" enctype="multipart/form-data">
                <input type="hidden" class="form-control" name="txtId" id="txtId" value="<?php echo $txtId; ?>" >
                <div class="form-check form-switch">
                    <label for="chkActivo">Activo</label>
                    <input class="form-check-input" type="checkbox" id="chkActivo" name="chkActivo" <?php if($chkActivo == "1") {echo ("checked"); } ?>>
                </div>
                <div class = "form-group">
                    <label for="exampleSelect1" class="form-label mt-1">Nombre documento*</label>
                    <input type="text" required class="form-control" name="txtNomDocumento" id="txtNomDocumento" value="<?php echo $txtNomDocumento; ?>">
                </div>
                <div class = "form-group">
                    <label for="exampleSelect1" class="form-label mt-1">Imagen</label>
                    <?php echo $txtFileNameImagen; ?>
                    <input type="file" class="form-control" name="txtFileImagen" id="txtFileImagen" >
                </div>
                <div class = "form-group">
                    <label for="exampleSelect1" class="form-label mt-1">Archivo</label>
                    <?php echo $txtFileNameAdjunto; ?>
                    <input type="file" class="form-control" name="txtFileAdjunto" id="txtFileAdjunto" >
                </div>
                
                <br/>
                <div class="btn-group" role="group" aria-label="">
                    <button type="submit" name="action" <?php if ($action=="Seleccionar" or $action=="Modificar"  ){echo ("disabled");} ?> value="Agregar" class="btn btn-outline-success" onclick="return confirm('¿Está seguro de agregar el registro?')">Agregar</button> &nbsp;
                    <button type="submit" name="action" <?php if ($action!="Seleccionar" and $action!="Modificar"){echo ("disabled");} ?> value="Modificar" class="btn btn-outline-warning" onclick="return confirm('¿Está seguro de modificar el registro?')">Modificar</button>&nbsp;
                    <button type="submit" name="action" formnovalidate="" value="Volver" class="btn btn-outline-info">Volver</button>
                </div>
            </form>
        </div>
    </div>
</div>
<div class="col-md-8">
        <form class="d-flex" method="GET">
            <input type="hidden" class="form-control" name="pagina" id="pagina" value="<?php echo $getPagina; ?>" >
            <input class="form-control me-sm-2" type="text" placeholder="filtrar" name="txtFiltro" id="txtFiltro" value="<?php echo ($txtFiltro!="")?$txtFiltro:""; ?>">
            <button class="btn btn-outline-info" name="action" type="submit" value="Filtrar">Filtrar</button>
        </form>
    <table class="table table-hover">
        <thead>
            <tr>
                <th>ID</th>
                <th>nombre</th>
                <th>Imagen</th>
                <th>Adjunto</th>
            </tr>
        </thead>
        <tbody>
            <?php 
            foreach($listaDocumentos as $doc) { ?>
            <tr>
                <td><?php echo $doc['id'] ?></td>
                <td><?php echo $doc['nombreDocumento'] ?></td>
                <td><?php echo $doc['imagen'] ?></td>
                <td><?php echo $doc['adjunto'] ?></td>
                <td>
                    <form method="post">
                        <input type="hidden" name="txtId" id="txtId" value="<?php echo $doc['id'] ?>">
                        <button type="submit" name="action" class="btn btn-outline-dark" value="Seleccionar">
                            <i type="submit" class="bi bi-check2-circle" style="font-size: 1rem; color: #BA0700;"></i>
                        </button>
                    </form>
                </td>
            </tr>
            <?php } ?>
        </tbody>
    </table>
    <div>
        <ul class="pagination">
            <li class="page-item <?php echo ($getPagina<=1)?"disabled":""; ?>">
                <a class="page-link" href="<?php echo $html; ?>?pagina=<?php echo $getPagina-1 ?>&txtFiltro=<?php echo $txtFiltro; ?>">&laquo;</a>
            </li>
            <?php for($i=0; $i< $paginas; $i++ ) { 
                    if((($i+1)%$paginadorSalto)==0){
                        echo("</ul><ul class='pagination'>");
                    } 
                ?>
            <li class="page-item <?php echo ($getPagina==$i+1)?"active":""; ?>">
                <a class="page-link" href="<?php echo $html; ?>?pagina=<?php echo $i+1 ?>&txtFiltro=<?php echo $txtFiltro; ?>"><?php echo $i+1 ?></a>
            </li>
            <?php } ?>
            <li class="page-item <?php echo ($getPagina>=$paginas)?"disabled":""; ?>">
                <a class="page-link" href="<?php echo $html; ?>?pagina=<?php echo $getPagina+1 ?>&txtFiltro=<?php echo $txtFiltro; ?>">&raquo;</a>
            </li>
        </ul>
    </div>
</div>

<?php include('./templates/pie.php'); ?>